@@ -3,7 +3,7 @@ import itertools
 from collections import defaultdict
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, Set, Tuple
 
-from moto.core import CloudFormationModel
+from moto.core.common_models import CloudFormationModel
 
 if TYPE_CHECKING:
     from moto.ec2.models.instances import Instance
@@ -11,6 +11,8 @@ if TYPE_CHECKING:
 from moto.ec2.models.availability_zones_and_regions import Zone
 
 from ..exceptions import (
+    DefaultSubnetAlreadyExistsInAvailabilityZoneError,
+    DefaultVpcDoesNotExistError,
     GenericInvalidParameterValueError,
     InvalidAvailabilityZoneError,
     InvalidCIDRBlockParameterError,
@@ -61,9 +63,9 @@ class Subnet(TaggedEC2Resource, CloudFormationModel):
         self.reserved_ips = [
             next(self._subnet_ip_generator) for _ in range(0, 3)
         ]  # Reserved by AWS
-        self._unused_ips: Set[
-            str
-        ] = set()  # if instance is destroyed hold IP here for reuse
+        self._unused_ips: Set[str] = (
+            set()
+        )  # if instance is destroyed hold IP here for reuse
         self._subnet_ips: Dict[str, "Instance"] = {}
         self.state = "available"
 
@@ -303,14 +305,32 @@ class SubnetBackend:
                 return subnets_per_zone[subnet_id]
         raise InvalidSubnetIdError(subnet_id)
 
-    def get_default_subnet(self, availability_zone: str) -> Subnet:
-        return [
-            subnet
-            for subnet in self.describe_subnets(
-                filters={"availabilityZone": availability_zone}
-            )
+    def get_default_subnets(self) -> Dict[str, Subnet]:
+        return {
+            subnet.availability_zone: subnet
+            for subnet in self.describe_subnets()
             if subnet.default_for_az
-        ][0]
+        }
+
+    def create_default_subnet(self, availability_zone: str) -> Subnet:
+        default_subnets = self.get_default_subnets()
+        if availability_zone in default_subnets:
+            raise DefaultSubnetAlreadyExistsInAvailabilityZoneError(
+                default_subnets[availability_zone].id, availability_zone
+            )
+
+        default_vpc = self.get_default_vpc()  # type: ignore[attr-defined]
+        if default_vpc is None:
+            raise DefaultVpcDoesNotExistError()
+
+        cidr_block = default_vpc.cidr_block
+        blocks = list(ipaddress.ip_network(cidr_block).subnets(new_prefix=20))
+        subnet = self.create_subnet(
+            vpc_id=default_vpc.id,
+            cidr_block=str(blocks[len(default_subnets)]),
+            availability_zone=availability_zone,
+        )
+        return subnet
 
     def create_subnet(
         self,
@@ -321,7 +341,6 @@ class SubnetBackend:
         availability_zone_id: Optional[str] = None,
         tags: Optional[Dict[str, Dict[str, str]]] = None,
     ) -> Subnet:
-
         subnet_id = random_subnet_id()
         # Validate VPC exists and the supplied CIDR block is a subnet of the VPC's
         vpc = self.get_vpc(vpc_id)  # type: ignore[attr-defined]
@@ -359,7 +378,7 @@ class SubnetBackend:
 
         # if this is the first subnet for an availability zone,
         # consider it the default
-        default_for_az = str(availability_zone not in self.subnets).lower()
+        default_for_az = str(len(self.subnets.get(availability_zone, [])) == 0).lower()  # type: ignore[arg-type]
         map_public_ip_on_launch = default_for_az
 
         if availability_zone is None and not availability_zone_id:
