@@ -349,7 +349,7 @@ class VPCEndPoint(TaggedEC2Resource, CloudFormationModel):
         client_token: Optional[str] = None,
         security_group_ids: Optional[List[str]] = None,
         tags: Optional[Dict[str, str]] = None,
-        private_dns_enabled: Optional[str] = None,
+        private_dns_enabled: Optional[bool] = None,
         destination_prefix_list_id: Optional[str] = None,
     ):
         self.ec2_backend = ec2_backend
@@ -709,7 +709,17 @@ class VPCBackend:
         if default_vpc:
             raise DefaultVpcAlreadyExists
         cidr_block = "172.31.0.0/16"
-        return self.create_vpc(cidr_block=cidr_block, is_default=True)
+        vpc = self.create_vpc(cidr_block=cidr_block, is_default=True)
+
+        for zone in self.describe_availability_zones():  # type: ignore[attr-defined]
+            self.create_default_subnet(zone.name)  # type: ignore[attr-defined]
+        return vpc
+
+    def get_default_vpc(self) -> Optional[VPC]:
+        for vpc in self.vpcs.values():
+            if vpc.is_default == "true":
+                return vpc
+        return None
 
     def create_vpc(
         self,
@@ -775,6 +785,15 @@ class VPCBackend:
         return matches
 
     def delete_vpc(self, vpc_id: str) -> VPC:
+        # Refuse to delete if there are dependent subnets
+        subnets = self.describe_subnets(filters={"vpc-id": vpc_id})  # type: ignore[attr-defined]
+        if subnets:
+            raise DependencyViolationError(
+                f"The vpc '{vpc_id}' has dependencies and cannot be deleted."
+            )
+
+        # TODO: Refuse to delete if there are dependent IGW
+
         # Do not delete if any VPN Gateway is attached
         vpn_gateways = self.describe_vpn_gateways(filters={"attachment.vpc-id": vpc_id})  # type: ignore[attr-defined]
         vpn_gateways = [
@@ -906,7 +925,7 @@ class VPCBackend:
         client_token: Optional[str] = None,
         security_group_ids: Optional[List[str]] = None,
         tags: Optional[Dict[str, str]] = None,
-        private_dns_enabled: Optional[str] = None,
+        private_dns_enabled: Optional[bool] = None,
     ) -> VPCEndPoint:
         vpc_endpoint_id = random_vpc_ep_id()
 
