@@ -77,9 +77,9 @@ class Cluster(BaseObject, CloudFormationModel):
         self.active_services_count = 0
         self.arn = f"arn:{get_partition(region_name)}:ecs:{region_name}:{account_id}:cluster/{cluster_name}"
         self.name = cluster_name
-        self.pending_tasks_count = 0
         self.registered_container_instances_count = 0
         self.running_tasks_count = 0
+        self.pending_tasks_count = 0
         self.status = "ACTIVE"
         self.region_name = region_name
         self.settings = cluster_settings or [
@@ -386,7 +386,7 @@ class Task(BaseObject, ManagedState):
         self.desired_status = "RUNNING"
         self.task_definition_arn = task_definition.arn
         self.overrides = overrides or {}
-        self.containers: List[Dict[str, Any]] = []
+        self.containers = [Container(task_definition)]
         self.started_by = started_by
         self.tags = tags or []
         self.launch_type = launch_type
@@ -451,6 +451,7 @@ class Task(BaseObject, ManagedState):
             response_object.pop("tags", None)
         response_object["taskArn"] = self.task_arn
         response_object["lastStatus"] = self.last_status
+        response_object["containers"] = [self.containers[0].response_object]
         return response_object
 
 
@@ -527,14 +528,6 @@ class CapacityProviderFailure(BaseObject):
 
 
 class Service(BaseObject, CloudFormationModel):
-    """Set the environment variable MOTO_ECS_SERVICE_RUNNING to a number of running tasks you want
-    the service to transition to, ie if set to 2:
-
-    MOTO_ECS_SERVICE_RUNNING=2
-
-    then describe_services call to return runningCount of the service AND deployment to 2
-    """
-
     def __init__(
         self,
         cluster: Cluster,
@@ -551,6 +544,7 @@ class Service(BaseObject, CloudFormationModel):
         platform_version: Optional[str] = None,
         network_configuration: Optional[Dict[str, Dict[str, List[str]]]] = None,
         propagate_tags: str = "NONE",
+        role_arn: Optional[str] = None,
     ):
         self.cluster_name = cluster.name
         self.cluster_arn = cluster.arn
@@ -572,6 +566,7 @@ class Service(BaseObject, CloudFormationModel):
         self.region_name = cluster.region_name
         self._account_id = backend.account_id
         self._backend = backend
+        self.role_arn = role_arn
 
         try:
             # negative running count not allowed, set to 0 if so
@@ -582,6 +577,7 @@ class Service(BaseObject, CloudFormationModel):
 
         self.running_count = ecs_running_count
         self.pending_count = desired_count - ecs_running_count
+
         if self.deployment_controller["type"] == "ECS":
             self.deployments = [
                 {
@@ -667,6 +663,8 @@ class Service(BaseObject, CloudFormationModel):
                     deployment["updatedAt"].replace(tzinfo=None)
                 )
         response_object["networkConfiguration"] = self.network_configuration
+        if self.role_arn:
+            response_object["roleArn"] = self.role_arn
 
         return response_object
 
@@ -765,6 +763,29 @@ class Service(BaseObject, CloudFormationModel):
         raise UnformattedGetAttTemplateException()
 
 
+class Container(BaseObject, CloudFormationModel):
+    def __init__(
+        self,
+        task_def: TaskDefinition,
+    ):
+        self.container_arn = f"{task_def.arn}/{str(mock_random.uuid4())}"
+        self.task_arn = task_def.arn
+
+        container_def = task_def.container_definitions[0]
+        self.image = container_def.get("image")
+        self.last_status = "PENDING"
+        self.exitCode = 0
+
+        self.network_interfaces: List[Dict[str, Any]] = []
+        self.health_status = "HEALTHY"
+
+        self.cpu = container_def.get("cpu")
+        self.memory = container_def.get("memory")
+        self.environment = container_def.get("environment")
+        self.name = container_def.get("name")
+        self.command = container_def.get("command")
+
+
 class ContainerInstance(BaseObject):
     def __init__(
         self,
@@ -997,6 +1018,12 @@ class EC2ContainerServiceBackend(BaseBackend):
     `MOTO_ECS_NEW_ARN=false`
 
     AWS reference: https://aws.amazon.com/blogs/compute/migrating-your-amazon-ecs-deployment-to-the-new-arn-and-resource-id-format-2/
+
+    Set the environment variable MOTO_ECS_SERVICE_RUNNING to a number of running tasks you want. For example:
+
+    MOTO_ECS_SERVICE_RUNNING=2
+
+    Every describe_services() will return runningCount AND deployment of 2
     """
 
     def __init__(self, region_name: str, account_id: str):
@@ -1091,6 +1118,20 @@ class EC2ContainerServiceBackend(BaseBackend):
             cluster.service_connect_defaults = service_connect_defaults
         return cluster
 
+    def update_cluster_resources(
+        self,
+        cluster: Cluster,
+        task_num: int,
+        task_state: Optional[str] = "RUNNING",
+    ) -> None:
+        """
+        Modify the number tasks running on the cluster.
+        """
+        if task_state == "RUNNING":
+            cluster.running_tasks_count += task_num
+        elif task_state == "PENDING":
+            cluster.pending_tasks_count += task_num
+
     def put_cluster_capacity_providers(
         self,
         cluster_name: str,
@@ -1393,6 +1434,7 @@ class EC2ContainerServiceBackend(BaseBackend):
                     self.update_container_instance_resources(
                         container_instance, resource_requirements
                     )
+                    self.update_cluster_resources(cluster, 1)
                     tasks.append(task)
                     self.tasks[cluster.name][task.task_arn] = task
                     placed_count += 1
@@ -1618,6 +1660,7 @@ class EC2ContainerServiceBackend(BaseBackend):
                         tasks[task].resource_requirements,  # type: ignore[arg-type]
                         removing=True,
                     )
+                    self.update_cluster_resources(cluster, -1, task_state="RUNNING")
                 tasks[task].last_status = "STOPPED"
                 tasks[task].desired_status = "STOPPED"
                 tasks[task].stopped_reason = reason
@@ -1648,6 +1691,7 @@ class EC2ContainerServiceBackend(BaseBackend):
         platform_version: Optional[str] = None,
         propagate_tags: str = "NONE",
         network_configuration: Optional[Dict[str, Dict[str, List[str]]]] = None,
+        role_arn: Optional[str] = None,
     ) -> Service:
         cluster = self._get_cluster(cluster_str)
 
@@ -1655,8 +1699,8 @@ class EC2ContainerServiceBackend(BaseBackend):
             task_definition = self.describe_task_definition(task_definition_str)
         else:
             task_definition = None
-        desired_count = desired_count if desired_count is not None else 0
 
+        desired_count = desired_count if desired_count is not None else 0
         launch_type = launch_type if launch_type is not None else "EC2"
         if launch_type not in ["EC2", "FARGATE"]:
             raise EcsClientException("launch type should be one of [EC2,FARGATE]")
@@ -1676,10 +1720,18 @@ class EC2ContainerServiceBackend(BaseBackend):
             platform_version=platform_version,
             propagate_tags=propagate_tags,
             network_configuration=network_configuration,
+            role_arn=role_arn,
         )
         cluster_service_pair = f"{cluster.name}:{service_name}"
         self.services[cluster_service_pair] = service
 
+        self.update_cluster_resources(
+            cluster, service.running_count, task_state="RUNNING"
+        )
+        self.update_cluster_resources(
+            cluster, service.pending_count, task_state="PENDING"
+        )
+
         return service
 
     def list_services(
@@ -1736,6 +1788,15 @@ class EC2ContainerServiceBackend(BaseBackend):
         force_new_deployment = service_properties.pop("force_new_deployment", False)
         cluster_service_pair = f"{cluster.name}:{service_name}"
 
+        # Zero out the service's logged tasks on the cluster.
+        service = self._get_service(cluster_str, service_name)
+        self.update_cluster_resources(
+            cluster, -service.running_count, task_state="RUNNING"
+        )
+        self.update_cluster_resources(
+            cluster, -service.pending_count, task_state="PENDING"
+        )
+
         if cluster_service_pair in self.services:
             current_service = self.services[cluster_service_pair]
             for prop_name, prop_val in service_properties.items():
@@ -1744,6 +1805,9 @@ class EC2ContainerServiceBackend(BaseBackend):
                     if prop_name == "desired_count":
                         current_service.__setattr__("running_count", prop_val)
                         current_service.__setattr__("pending_count", 0)
+                        self.update_cluster_resources(
+                            cluster, prop_val, task_state="RUNNING"
+                        )
             if task_definition_str:
                 self.describe_task_definition(task_definition_str)
                 current_service.task_definition = task_definition_str
@@ -1774,6 +1838,12 @@ class EC2ContainerServiceBackend(BaseBackend):
             # A service is not immediately removed - just marked as inactive
             # It is only deleted later on
             # https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ecs.html#ECS.Client.delete_service
+            self.update_cluster_resources(
+                cluster, -service.running_count, task_state="RUNNING"
+            )
+            self.update_cluster_resources(
+                cluster, -service.pending_count, task_state="PENDING"
+            )
             service.status = "INACTIVE"
             service.pending_count = 0
             return service
