@@ -396,6 +396,22 @@ class GlueResponse(BaseResponse):
         job_run = self.glue_backend.get_job_run(name, run_id)  # type: ignore[arg-type]
         return json.dumps({"JobRun": job_run.as_dict()})
 
+    def get_job_runs(self) -> str:
+        job_name = self._get_param("JobName")
+        next_token = self._get_param("NextToken")
+        max_results = self._get_int_param("MaxResults")
+        job_runs, next_token = self.glue_backend.get_job_runs(
+            job_name,
+            next_token=next_token,
+            max_results=max_results,
+        )
+        return json.dumps(
+            dict(
+                JobRuns=[job_run.as_dict() for job_run in job_runs],
+                NextToken=next_token,
+            )
+        )
+
     def list_jobs(self) -> str:
         next_token = self._get_param("NextToken")
         max_results = self._get_int_param("MaxResults")
@@ -736,3 +752,126 @@ class GlueResponse(BaseResponse):
         name = self.parameters.get("Name")
         self.glue_backend.delete_trigger(name)  # type: ignore[arg-type]
         return json.dumps({"Name": name})
+
+    def get_dev_endpoints(self) -> str:
+        next_token = self._get_param("NextToken")
+        max_results = self._get_int_param("MaxResults")
+
+        endpoints, next_token = self.glue_backend.get_dev_endpoints(
+            next_token=next_token, max_results=max_results
+        )
+
+        return json.dumps(
+            dict(
+                DevEndpoints=[endpoint.as_dict() for endpoint in endpoints],
+                NextToken=next_token,
+            )
+        )
+
+    def create_dev_endpoint(self) -> str:
+        endpoint_name = self._get_param("EndpointName")
+        role_arn = self._get_param("RoleArn")
+        security_group_ids = self._get_param("SecurityGroupIds")
+        subnet_id = self._get_param("SubnetId")
+        public_key = self._get_param("PublicKey")
+        public_keys = self._get_param("PublicKeys")
+        number_of_nodes = self._get_int_param("NumberOfNodes")
+        worker_type = self._get_param("WorkerType", "Standard")
+        glue_version = self._get_param("GlueVersion", "1.0")
+        number_of_workers = self._get_int_param("NumberOfWorkers")
+        extra_python_libs_s3_path = self._get_param("ExtraPythonLibsS3Path")
+        extra_jars_s3_path = self._get_param("ExtraJarsS3Path")
+        security_configuration = self._get_param("SecurityConfiguration")
+        tags = self._get_param("Tags")
+        arguments = self._get_param("Arguments")
+
+        dev_endpoint = self.glue_backend.create_dev_endpoint(
+            endpoint_name=endpoint_name,
+            role_arn=role_arn,
+            security_group_ids=security_group_ids,
+            subnet_id=subnet_id,
+            public_key=public_key,
+            public_keys=public_keys,
+            number_of_nodes=number_of_nodes,
+            worker_type=worker_type,
+            glue_version=glue_version,
+            number_of_workers=number_of_workers,
+            extra_python_libs_s3_path=extra_python_libs_s3_path,
+            extra_jars_s3_path=extra_jars_s3_path,
+            security_configuration=security_configuration,
+            tags=tags,
+            arguments=arguments,
+        )
+
+        return json.dumps(dev_endpoint.as_dict())
+
+    def get_dev_endpoint(self) -> str:
+        endpoint_name = self._get_param("EndpointName")
+        dev_endpoint = self.glue_backend.get_dev_endpoint(endpoint_name)
+        return json.dumps({"DevEndpoint": dev_endpoint.as_dict()})
+
+    def create_connection(self) -> str:
+        catalog_id = self._get_param("CatalogId")
+        connection_input = self._get_param("ConnectionInput")
+        tags = self._get_param("Tags")
+        create_connection_status = self.glue_backend.create_connection(
+            catalog_id=catalog_id,
+            connection_input=connection_input,
+            tags=tags,
+        )
+        return json.dumps(dict(CreateConnectionStatus=create_connection_status))
+
+    def get_connection(self) -> str:
+        catalog_id = self._get_param("CatalogId")
+        name = self._get_param("Name")
+        hide_password = self._get_param("HidePassword")
+        apply_override_for_compute_environment = self._get_param(
+            "ApplyOverrideForComputeEnvironment"
+        )
+        connection = self.glue_backend.get_connection(
+            catalog_id=catalog_id,
+            name=name,
+            hide_password=hide_password,
+            apply_override_for_compute_environment=apply_override_for_compute_environment,
+        )
+        return json.dumps(dict(Connection=connection.as_dict()))
+
+    def get_connections(self) -> str:
+        catalog_id = self._get_param("CatalogId")
+        filter = self._get_param("Filter")
+        hide_password = self._get_param("HidePassword")
+        next_token = self._get_param("NextToken")
+        max_results = self._get_param("MaxResults")
+        connections, next_token = self.glue_backend.get_connections(
+            catalog_id=catalog_id,
+            filter=filter,
+            hide_password=hide_password,
+            next_token=next_token,
+            max_results=max_results,
+        )
+        connection_list = [connection.as_dict() for connection in connections]
+        return json.dumps(dict(ConnectionList=connection_list, NextToken=next_token))
+
+    def put_data_catalog_encryption_settings(self) -> str:
+        params = self.parameters
+        catalog_id = params.get("CatalogId", None)
+        data_catalog_encryption_settings = params.get(
+            "DataCatalogEncryptionSettings", {}
+        )
+
+        self.glue_backend.put_data_catalog_encryption_settings(
+            catalog_id=catalog_id,
+            data_catalog_encryption_settings=data_catalog_encryption_settings,
+        )
+
+        return json.dumps({})
+
+    def get_data_catalog_encryption_settings(self) -> str:
+        params = self.parameters
+        catalog_id = params.get("CatalogId", None)
+
+        response = self.glue_backend.get_data_catalog_encryption_settings(
+            catalog_id=catalog_id,
+        )
+
+        return json.dumps(response)
