@@ -1,8 +1,10 @@
 from typing import Any, Dict, Iterator, List, Optional, Tuple
 
 from moto.acm.models import AWSCertificateManagerBackend, acm_backends
+from moto.appsync.models import AppSyncBackend, appsync_backends
 from moto.awslambda.models import LambdaBackend, lambda_backends
 from moto.backup.models import BackupBackend, backup_backends
+from moto.cloudfront.models import CloudFrontBackend, cloudfront_backends
 from moto.core.base_backend import BackendDict, BaseBackend
 from moto.core.exceptions import RESTError
 from moto.dynamodb.models import DynamoDBBackend, dynamodb_backends
@@ -12,10 +14,17 @@ from moto.efs.models import EFSBackend, efs_backends
 from moto.elb.models import ELBBackend, elb_backends
 from moto.elbv2.models import ELBv2Backend, elbv2_backends
 from moto.emr.models import ElasticMapReduceBackend, emr_backends
+from moto.events.models import EventsBackend, events_backends
 from moto.glacier.models import GlacierBackend, glacier_backends
 from moto.glue.models import GlueBackend, glue_backends
+from moto.kafka.models import KafkaBackend, kafka_backends
 from moto.kinesis.models import KinesisBackend, kinesis_backends
+from moto.kinesisanalyticsv2.models import (
+    KinesisAnalyticsV2Backend,
+    kinesisanalyticsv2_backends,
+)
 from moto.kms.models import KmsBackend, kms_backends
+from moto.lexv2models.models import LexModelsV2Backend, lexv2models_backends
 from moto.logs.models import LogsBackend, logs_backends
 from moto.moto_api._internal import mock_random
 from moto.rds.models import RDSBackend, rds_backends
@@ -33,7 +42,7 @@ from moto.utilities.utils import get_partition
 from moto.workspaces.models import WorkSpacesBackend, workspaces_backends
 from moto.workspacesweb.models import WorkSpacesWebBackend, workspacesweb_backends
 
-# Left: EC2 ElastiCache RDS ELB CloudFront Lambda EMR Glacier Kinesis Redshift Route53
+# Left: EC2 ElastiCache RDS ELB Lambda EMR Glacier Kinesis Redshift Route53
 # StorageGateway DynamoDB MachineLearning ACM DirectConnect DirectoryService CloudHSM
 # Inspector Elasticsearch
 
@@ -48,6 +57,10 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
         # fit in the current request. As we only store generators
         # there is really no point cleaning up
 
+    @property
+    def appsync_backend(self) -> AppSyncBackend:
+        return appsync_backends[self.account_id][self.region_name]
+
     @property
     def s3_backend(self) -> S3Backend:
         return s3_backends[self.account_id][self.partition]
@@ -68,6 +81,10 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
     def elbv2_backend(self) -> ELBv2Backend:
         return elbv2_backends[self.account_id][self.region_name]
 
+    @property
+    def events_backend(self) -> EventsBackend:
+        return events_backends[self.account_id][self.region_name]
+
     @property
     def glue_backend(self) -> GlueBackend:
         return glue_backends[self.account_id][self.region_name]
@@ -76,6 +93,10 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
     def kinesis_backend(self) -> KinesisBackend:
         return kinesis_backends[self.account_id][self.region_name]
 
+    @property
+    def kinesisanalyticsv2_backend(self) -> KinesisAnalyticsV2Backend:
+        return kinesisanalyticsv2_backends[self.account_id][self.region_name]
+
     @property
     def kms_backend(self) -> KmsBackend:
         return kms_backends[self.account_id][self.region_name]
@@ -154,10 +175,24 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
             return workspacesweb_backends[self.account_id][self.region_name]
         return None
 
+    @property
+    def kafka_backend(self) -> KafkaBackend:
+        return kafka_backends[self.account_id][self.region_name]
+
     @property
     def sagemaker_backend(self) -> SageMakerModelBackend:
         return sagemaker_backends[self.account_id][self.region_name]
 
+    @property
+    def lexv2_backend(self) -> Optional[LexModelsV2Backend]:
+        if self.region_name in lexv2models_backends[self.account_id].regions:
+            return lexv2models_backends[self.account_id][self.region_name]
+        return None
+
+    @property
+    def cloudfront_backend(self) -> CloudFrontBackend:
+        return cloudfront_backends[self.account_id][self.partition]
+
     def _get_resources_generator(
         self,
         tag_filters: Optional[List[Dict[str, Any]]] = None,
@@ -221,6 +256,19 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
                     continue
                 yield {"ResourceARN": f"{certificate.arn}", "Tags": tags}
 
+        # AppSync
+        if not resource_type_filters or "appsync" in resource_type_filters:
+            for api in self.appsync_backend.graphql_apis.values():
+                tags = self.appsync_backend.tagger.list_tags_for_resource(api.arn)[
+                    "Tags"
+                ]
+                if not tags or not tag_filter(
+                    tags
+                ):  # Skip if no tags, or invalid filter
+                    continue
+
+                yield {"ResourceARN": f"{api.arn}", "Tags": tags}
+
         # Backup
         if not resource_type_filters or "backup" in resource_type_filters:
             for vault in self.backup_backend.vaults.values():
@@ -264,6 +312,22 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
             except Exception:
                 pass
 
+        # Cloudfront
+        if (
+            not resource_type_filters
+            or "cloudfront" in resource_type_filters
+            or "cloudfront:distributions" in resource_type_filters
+        ):
+            for dist in self.cloudfront_backend.distributions.values():
+                tags = self.cloudfront_backend.tagger.list_tags_for_resource(dist.arn)[
+                    "Tags"
+                ]
+                if (
+                    not tag_filter(tags) or len(tags) == 0
+                ):  # Skip if no tags, or invalid filter
+                    continue
+                yield {"ResourceARN": f"{dist.arn}", "Tags": tags}
+
         # ECS
         if not resource_type_filters or "ecs:service" in resource_type_filters:
             for service in self.ecs_backend.services.values():
@@ -411,6 +475,22 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
 
         # EMR Cluster
 
+        # Events
+        if (
+            not resource_type_filters
+            or "events" in resource_type_filters
+            or "events:event-bus" in resource_type_filters
+        ):
+            for bus in self.events_backend.event_buses.values():
+                tags = self.events_backend.tagger.list_tags_for_resource(bus.arn)[
+                    "Tags"
+                ]
+                if (
+                    not tag_filter(tags) or len(tags) == 0
+                ):  # Skip if no tags, or invalid filter
+                    continue
+                yield {"ResourceARN": f"{bus.arn}", "Tags": tags}
+
         # Glacier Vault
 
         # Glue
@@ -438,6 +518,21 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
 
         # Kinesis
 
+        # KinesisAnalyticsV2
+        if self.kinesisanalyticsv2_backend and (
+            not resource_type_filters or "kinesisanalyticsv2" in resource_type_filters
+        ):
+            for application in self.kinesisanalyticsv2_backend.applications.values():
+                tags = self.kinesisanalyticsv2_backend.tagger.list_tags_for_resource(
+                    application.application_arn
+                )["Tags"]
+                if not tags or not tag_filter(tags):
+                    continue
+                yield {
+                    "ResourceARN": application.application_arn,
+                    "Tags": tags,
+                }
+
         # KMS
         if not resource_type_filters or "kms" in resource_type_filters:
             for kms_key in self.kms_backend.list_keys():
@@ -450,6 +545,31 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
 
                 yield {"ResourceARN": f"{kms_key.arn}", "Tags": tags}
 
+        # LexV2
+        if self.lexv2_backend:
+            lex_v2_resource_map: Dict[str, Dict[str, Any]] = {
+                "lexv2:bot": self.lexv2_backend.bots,
+                "lexv2:bot-alias": self.lexv2_backend.bot_aliases,
+            }
+            for resource_type, resource_source in lex_v2_resource_map.items():
+                if (
+                    not resource_type_filters
+                    or "lexv2" in resource_type_filters
+                    or resource_type in resource_type_filters
+                ):
+                    for resource in resource_source.values():
+                        bot_tags = self.lexv2_backend.list_tags_for_resource(
+                            resource.arn
+                        )
+
+                        tags = format_tags(bot_tags)
+                        if not tags or not tag_filter(tags):
+                            continue
+                        yield {
+                            "ResourceARN": resource.arn,
+                            "Tags": tags,
+                        }
+
         # LOGS
         if (
             not resource_type_filters
@@ -466,11 +586,11 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
                 yield {"ResourceARN": group.arn, "Tags": tags}
 
         # RDS resources
-        resource_map: Dict[str, Dict[str, Any]] = {
-            "rds:cluster": self.rds_backend.clusters,
-            "rds:db": self.rds_backend.databases,
-            "rds:snapshot": self.rds_backend.database_snapshots,
-            "rds:cluster-snapshot": self.rds_backend.cluster_snapshots,
+        resource_map: dict[str, dict[str, Any]] = {
+            "rds:cluster": dict(self.rds_backend.clusters),
+            "rds:db": dict(self.rds_backend.databases),
+            "rds:snapshot": dict(self.rds_backend.database_snapshots),
+            "rds:cluster-snapshot": dict(self.rds_backend.cluster_snapshots),
             "rds:db-proxy": self.rds_backend.db_proxies,
         }
         for resource_type, resource_source in resource_map.items():
@@ -610,6 +730,22 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
                     "Tags": tags,
                 }
 
+        # Kafka (MSK)
+        if self.kafka_backend and (
+            not resource_type_filters or "kafka" in resource_type_filters
+        ):
+            for msk_cluster in self.kafka_backend.clusters.values():
+                tag_dict = self.kafka_backend.list_tags_for_resource(msk_cluster.arn)
+                tags = [{"Key": key, "Value": value} for key, value in tag_dict.items()]
+
+                if not tags or not tag_filter(tags):
+                    continue
+
+                yield {
+                    "ResourceARN": msk_cluster.arn,
+                    "Tags": tags,
+                }
+
         # Workspaces Web
         if self.workspacesweb_backends and (
             not resource_type_filters or "workspaces-web" in resource_type_filters
