@@ -33,12 +33,40 @@ from moto.route53.exceptions import (
 from moto.utilities.paginator import paginate
 from moto.utilities.utils import PARTITION_NAMES, get_partition
 
+from ..utilities.id_generator import ExistingIds, ResourceIdentifier, Tags, moto_id
 from .utils import PAGINATION_MODEL, validate_domain_name
 
 ROUTE53_ID_CHOICE = string.ascii_uppercase + string.digits
+LOGS_GROUP_REGION = "us-east-1"
+LOGS_GROUP_ARN_REGEX = re.compile(
+    rf"arn:aws:logs:{LOGS_GROUP_REGION}:\d{{12}}:log-group:.+"
+)
 
 
-def create_route53_zone_id() -> str:
+class HostedZoneIdentifier(ResourceIdentifier):
+    service = "route53"
+    resource = "hosted_zone"
+
+    def __init__(self, account_id: str, name: str, delegation_set_id: Optional[str]):
+        # the region is left blank as route53 is a global service
+        super().__init__(
+            account_id=account_id,
+            region="",
+            name=".".join((name, delegation_set_id or "")),
+        )
+
+    def generate(self, existing_ids: ExistingIds = None, tags: Tags = None) -> str:
+        return create_route53_zone_id(
+            resource_identifier=self, existing_ids=existing_ids, tags=tags
+        )
+
+
+@moto_id
+def create_route53_zone_id(  # type: ignore
+    resource_identifier: ResourceIdentifier,
+    existing_ids: ExistingIds = None,
+    tags: Tags = None,
+) -> str:
     # New ID's look like this Z1RWWTK7Y8UDDQ
     return "".join([random.choice(ROUTE53_ID_CHOICE) for _ in range(0, 15)])
 
@@ -564,7 +592,9 @@ class Route53Backend(BaseBackend):
     ) -> FakeZone:
         if self._has_prev_conflicting_domain(name, delegation_set_id):
             raise ConflictingDomainExists(name, delegation_set_id)
-        new_id = create_route53_zone_id()
+        new_id = HostedZoneIdentifier(
+            self.account_id, name, delegation_set_id
+        ).generate(existing_ids=list(self.zones.keys()))
         caller_reference = caller_reference or create_route53_caller_reference()
         delegation_set = self.create_reusable_delegation_set(
             caller_reference=f"DelSet_{name}", delegation_set_id=delegation_set_id
@@ -647,10 +677,12 @@ class Route53Backend(BaseBackend):
             return self.resource_tags[resource_id]
         return {}
 
-    def list_tags_for_resources(self, resource_ids: List[str]) -> Dict[str, str]:
-        resources = {}
+    def list_tags_for_resources(self, resource_ids: List[str]) -> List[Dict[str, Any]]:
+        resources = []
         for id in resource_ids:
-            resources.update(self.list_tags_for_resource(id))
+            resource_set = {"ResourceId": id, "Tags": {}}
+            resource_set["Tags"] = self.list_tags_for_resource(id)
+            resources.append(resource_set)
         return resources
 
     def list_resource_record_sets(
@@ -873,21 +905,8 @@ class Route53Backend(BaseBackend):
     def get_health_check_status(self) -> None:
         pass  # Logic implemented in responses.py
 
-    @staticmethod
-    def _validate_arn(region: str, arn: str) -> None:
-        match = re.match(
-            rf"arn:{get_partition(region)}:logs:{region}:\d{{12}}:log-group:.+", arn
-        )
-        if not arn or not match:
-            raise InvalidCloudWatchArn()
-
-        # The CloudWatch Logs log group must be in the "us-east-1" region.
-        match = re.match(r"^(?:[^:]+:){3}(?P<region>[^:]+).*", arn)
-        if not match or match.group("region") != "us-east-1":
-            raise InvalidCloudWatchArn()
-
     def create_query_logging_config(
-        self, region: str, hosted_zone_id: str, log_group_arn: str
+        self, hosted_zone_id: str, log_group_arn: str
     ) -> QueryLoggingConfig:
         """Process the create_query_logging_config request."""
         # Does the hosted_zone_id exist?
@@ -899,7 +918,8 @@ class Route53Backend(BaseBackend):
             raise NoSuchHostedZone(hosted_zone_id)
 
         # Ensure CloudWatch Logs log ARN is valid, otherwise raise an error.
-        self._validate_arn(region, log_group_arn)
+        if not log_group_arn or not re.match(LOGS_GROUP_ARN_REGEX, log_group_arn):
+            raise InvalidCloudWatchArn()
 
         # Note:  boto3 checks the resource policy permissions before checking
         # whether the log group exists.  moto doesn't have a way of checking
@@ -911,9 +931,11 @@ class Route53Backend(BaseBackend):
 
         from moto.logs import logs_backends  # pylint: disable=import-outside-toplevel
 
-        log_groups = logs_backends[self.account_id][region].describe_log_groups()
+        log_groups = logs_backends[self.account_id][
+            LOGS_GROUP_REGION
+        ].describe_log_groups()
         for entry in log_groups[0] if log_groups else []:
-            if log_group_arn == entry["arn"]:
+            if log_group_arn == f"{entry.arn}:*":
                 break
         else:
             # There is no CloudWatch Logs log group with the specified ARN.
