@@ -203,6 +203,26 @@ class IllegalLocationConstraintException(S3ClientError):
         )
 
 
+class IncompatibleLocationConstraintException(S3ClientError):
+    code = 400
+
+    def __init__(self, location: str) -> None:
+        super().__init__(
+            "IllegalLocationConstraintException",
+            f"The {location} location constraint is incompatible for the region specific endpoint this request was sent to.",
+        )
+
+
+class InvalidLocationConstraintException(S3ClientError):
+    code = 400
+
+    def __init__(self) -> None:
+        super().__init__(
+            "InvalidLocationConstraint",
+            "The specified location-constraint is not valid",
+        )
+
+
 class MalformedXML(S3ClientError):
     code = 400
 
@@ -497,6 +517,13 @@ class InvalidContinuationToken(S3ClientError):
         )
 
 
+class InvalidBucketState(S3ClientError):
+    code = 400
+
+    def __init__(self, msg: str):
+        super().__init__("InvalidBucketState", msg)
+
+
 class InvalidObjectState(BucketError):
     code = 403
 
@@ -517,6 +544,13 @@ class LockNotEnabled(S3ClientError):
         super().__init__("InvalidRequest", "Bucket is missing ObjectLockConfiguration")
 
 
+class MissingRequestBody(S3ClientError):
+    code = 400
+
+    def __init__(self) -> None:
+        super().__init__("MissingRequestBodyError", "Request Body is empty")
+
+
 class AccessDeniedByLock(S3ClientError):
     code = 400
 
@@ -524,11 +558,14 @@ class AccessDeniedByLock(S3ClientError):
         super().__init__("AccessDenied", "Access Denied")
 
 
-class InvalidContentMD5(S3ClientError):
+class MissingUploadObjectWithObjectLockHeaders(S3ClientError):
     code = 400
 
     def __init__(self) -> None:
-        super().__init__("InvalidContentMD5", "Content MD5 header is invalid")
+        super().__init__(
+            "MissingUploadObjectWithObjectLockHeaders",
+            "Content-MD5 or x-amz-sdk-checksum-algorithm header required to upload an object with a retention period configured using Object Lock",
+        )
 
 
 class BucketNeedsToBeNew(S3ClientError):
@@ -538,16 +575,6 @@ class BucketNeedsToBeNew(S3ClientError):
         super().__init__("InvalidBucket", "Bucket needs to be empty")
 
 
-class BucketMustHaveLockeEnabled(S3ClientError):
-    code = 400
-
-    def __init__(self) -> None:
-        super().__init__(
-            "InvalidBucketState",
-            "Object Lock configuration cannot be enabled on existing buckets",
-        )
-
-
 class CopyObjectMustChangeSomething(S3ClientError):
     code = 400
 
@@ -593,21 +620,11 @@ class HeadOnDeleteMarker(Exception):
         self.marker = marker
 
 
-class DaysMustNotProvidedForSelectRequest(S3ClientError):
-    code = 400
+class MethodNotAllowed(S3ClientError):
+    code = 405
 
     def __init__(self) -> None:
         super().__init__(
-            "DaysMustNotProvidedForSelectRequest",
-            "`Days` must not be provided for select requests",
-        )
-
-
-class DaysMustProvidedExceptForSelectRequest(S3ClientError):
-    code = 400
-
-    def __init__(self) -> None:
-        super().__init__(
-            "DaysMustProvidedExceptForSelectRequest",
-            "`Days` must be provided except for select requests",
+            "MethodNotAllowed",
+            "The specified method is not allowed against this resource.",
         )
